package javax.swing.event;

import javax.swing.RowSorter;
import java.util.EventObject;

public class RowSorterEvent extends EventObject
{
    private RowSorterEvent.Type type;
    private int[] oldViewToModel;
    
    public RowSorterEvent(RowSorter rowSorter) {
        this(rowSorter, RowSorterEvent.Type.SORT_ORDER_CHANGED, (int[])null);
    }
    
    public RowSorterEvent(RowSorter source, RowSorterEvent.Type type, int[] oldViewToModel) {
        super(source);
        if (type == null) {
            throw new IllegalArgumentException("type must be non-null");
        }
        this.type = type;
        this.oldViewToModel = oldViewToModel;
        return;
    }
    
    @Override
    public RowSorter getSource() {
        return (RowSorter)super.getSource();
    }
    
    public RowSorterEvent.Type getType() {
        return this.type;
    }
    
    public int convertPreviousRowIndexToModel(int n) {
        if (this.oldViewToModel != null && n >= 0 && n < this.oldViewToModel.length) {
            return this.oldViewToModel[n];
        }
        return -1;
    }
    
    public int getPreviousRowCount() {
        return (this.oldViewToModel == null) ? 0 : this.oldViewToModel.length;
    }
    
    public enum Type
    {
        SORT_ORDER_CHANGED, 
        SORTED;
    }
}
